==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebContentPaneDescriptionMetadata } from "./WebContentPaneDescriptionMetadata";
import { WebPaneHeaderElementDescriptionMetadata } from "./WebPaneHeaderElementDescriptionMetadata";
import { WebPaneHeaderConnectionEventArgsDetailDescription } from "./WebPaneHeaderConnectionEventArgsDetailDescription";
/**
 * @hidden
 */
var WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata, _super);
    function WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata.a == null) {
            WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata.c(WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata.a);
        }
        if (a.k(WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata.a);
        WebContentPaneDescriptionMetadata.d(a);
        WebPaneHeaderElementDescriptionMetadata.d(a);
    };
    WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PaneHeaderConnectionEventArgsDetail");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("__skipSuffix", "Boolean");
        a.item("Pane", "ExportedType:WebContentPane");
        a.item("Element", "ExportedType:WebPaneHeaderElement");
    };
    WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata.d = function (a) {
        WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata.b(a);
        a.ad("WebPaneHeaderConnectionEventArgsDetail", function () { return new WebPaneHeaderConnectionEventArgsDetailDescription(); });
        a.ac("WebPaneHeaderConnectionEventArgsDetail", WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata.a);
    };
    WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata.$t = markType(WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata, 'WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata');
    WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata.a = null;
    return WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata;
}(Base));
export { WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebContentPaneDescriptionMetadata } from "./WebContentPaneDescriptionMetadata";
import { WebPaneHeaderElementDescriptionMetadata } from "./WebPaneHeaderElementDescriptionMetadata";
import { WebPaneHeaderConnectionEventArgsDetailDescription } from "./WebPaneHeaderConnectionEventArgsDetailDescription";
/**
 * @hidden
 */
var WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata, _super);
    function WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata.a == null) {
            WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata.c(WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata.a);
        }
        if (a.k(WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata.a);
        WebContentPaneDescriptionMetadata.d(a);
        WebPaneHeaderElementDescriptionMetadata.d(a);
    };
    WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PaneHeaderConnectionEventArgsDetail");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("__marshalByValue", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Pane", "ExportedType:WebContentPane");
        a.item("Element", "ExportedType:WebPaneHeaderElement");
    };
    WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata.d = function (a) {
        WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata.b(a);
        a.ae("WebPaneHeaderConnectionEventArgsDetail", function () { return new WebPaneHeaderConnectionEventArgsDetailDescription(); });
        a.ad("WebPaneHeaderConnectionEventArgsDetail", WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata.a);
    };
    WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata.$t = markType(WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata, 'WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata');
    WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata.a = null;
    return WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata;
}(Base));
export { WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata };
